var searchData=
[
  ['octave_5fapi_5fversion_5fnumber',['OCTAVE_API_VERSION_NUMBER',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1254fb4e5ab79f0fdb1edb9d6b387f58',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['octave_5ferror_5foccurred',['Octave_Error_Occurred',['../plplot__octaveOCTAVE__wrap_8cxx.html#aeef1c9b2220cc590521fe43f74bea0c9',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['octave_5ffunc',['octave_func',['../plplot__octaveOCTAVE__wrap_8cxx.html#a31d42c9b8612a55f0f9b6d0ed6936c0c',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['octave_5fset_5fimmutable',['octave_set_immutable',['../plplot__octaveOCTAVE__wrap_8cxx.html#adf5ca0c253f8f1175ad6ec3198339e12',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['octave_5fswig_5fpacked',['octave_swig_packed',['../classoctave__swig__packed.html',1,'octave_swig_packed'],['../classoctave__swig__packed.html#a7fb233507a6efc83a4bebc2dd2f8ad34',1,'octave_swig_packed::octave_swig_packed()']]],
  ['octave_5fswig_5fref',['octave_swig_ref',['../classoctave__swig__ref.html',1,'octave_swig_ref'],['../classoctave__swig__ref.html#ade9ab737a9d019a2edc7d238442f1354',1,'octave_swig_ref::octave_swig_ref()']]],
  ['octave_5fswig_5ftype',['octave_swig_type',['../classoctave__swig__type.html',1,'octave_swig_type'],['../classoctave__swig__type.html#a0f52916c2d5f9d56f96fe3d7b2c5fb3b',1,'octave_swig_type::octave_swig_type(const octave_swig_type &amp;x)'],['../classoctave__swig__type.html#a66c9d24f4c10cf5f1ba4375467fb4b69',1,'octave_swig_type::octave_swig_type(void *_ptr=0, const swig_type_info *_type=0, int _own=0, bool _always_static=false)']]],
  ['octave_5fvalue_5fref',['octave_value_ref',['../structoctave__value__ref.html',1,'octave_value_ref'],['../structoctave__value__ref.html#ab8bd77f03124b6ff2dce4d814c69f933',1,'octave_value_ref::octave_value_ref()']]],
  ['of',['OF',['../ps_8h.html#a37666c9af451b99166c96df28aec5395',1,'ps.h']]],
  ['offset',['offset',['../struct__plm__format.html#aa5e62c8c1ea4026ab7b4d5e7fe4379fe',1,'_plm_format::offset()'],['../plmap_8c.html#a21005f9f4e2ce7597c5eb4351816d7e2',1,'OFFSET():&#160;plmap.c']]],
  ['offset1',['offset1',['../structQSASConfigStruct.html#a8b404820878eee60a2dede7bd4601e06',1,'QSASConfigStruct::offset1()'],['../structTAI__UTC.html#a95eb25905e36f51b1dd3b14fa100d931',1,'TAI_UTC::offset1()']]],
  ['offset2',['offset2',['../structQSASConfigStruct.html#a4fe06a80b0e8aeaece961d4058766a92',1,'QSASConfigStruct::offset2()'],['../structTAI__UTC.html#a65455014519f456daa9106f56659397d',1,'TAI_UTC::offset2()']]],
  ['ok',['OK',['../plshade_8c.html#aba51915c87d64af47fb1cc59348961c9',1,'plshade.c']]],
  ['old_5fsoffset',['old_soffset',['../structPLCairo.html#a12edf6e15a7faef7af76269423dce238',1,'PLCairo']]],
  ['old_5fsscale',['old_sscale',['../structPLCairo.html#a53a3a8d2d8f7bfd556c6dbb2e9afb8b7',1,'PLCairo']]],
  ['oldhiview',['oldhiview',['../plot3d_8c.html#af35e0f7b0a9113c6ae7a70341e8d3fd6',1,'plot3d.c']]],
  ['oldloview',['oldloview',['../plot3d_8c.html#a391febef01caa614ae612952a95aac25',1,'plot3d.c']]],
  ['on_5fright_5fside',['on_right_side',['../delaunay_8c.html#a0fd0f63831b1479599a0dd82bdfede8e',1,'delaunay.c']]],
  ['oncreate',['OnCreate',['../classwxPLplotwindow.html#a09fe8cf92d3ccae0e58f1dd92051d684',1,'wxPLplotwindow']]],
  ['onerase',['OnErase',['../classwxPLplotwindow.html#ad184b76db6081d2e4bdde5f6854eca7c',1,'wxPLplotwindow']]],
  ['onew2b',['ONEW2B',['../classplplot.html#a682ba4d7edb5b72c8768df356142ebb0',1,'plplot::ONEW2B()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a38be4ac9a54000d51e4693bb5eedddf8',1,'plplot.core.plplotjavacConstants.ONEW2B()'],['../plplot_8h.html#a6e483ccfaad62129bfd0c7f60ff58d9a',1,'ONEW2B():&#160;plplot.h'],['../namespaceplplotc.html#a24af40303ce79b0ad7d3734512ca0801',1,'plplotc.ONEW2B()']]],
  ['onew2b_5fget',['ONEW2B_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a48108b997959f8917ea9405eeba4a127',1,'plplot::core::plplotjavacJNI']]],
  ['onew2d',['ONEW2D',['../classplplot.html#a778b78c3e46e3647c5b8ce171f26d437',1,'plplot::ONEW2D()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a20630324890f6d0e462b477cd861babc',1,'plplot.core.plplotjavacConstants.ONEW2D()'],['../plplot_8h.html#ac40cfbf950fe5727d3de6d31abc6c189',1,'ONEW2D():&#160;plplot.h'],['../namespaceplplotc.html#ae98a5cc86ba0792db304008fda820c99',1,'plplotc.ONEW2D()']]],
  ['onew2d_5fget',['ONEW2D_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#ac60c7e39ad16613ba0a03163d40943c7',1,'plplot::core::plplotjavacJNI']]],
  ['onpaint',['OnPaint',['../classwxPLplotwindow.html#a53f657e3771b953d80ad077e7add1594',1,'wxPLplotwindow']]],
  ['onsize',['OnSize',['../classwxPLplotwindow.html#aa4b386e34069cb93a2c47d9e986eb8bb',1,'wxPLplotwindow']]],
  ['open',['open',['../structcdImageStruct.html#af6d152248bfa7637e35b08427f099c0a',1,'cdImageStruct']]],
  ['open_5fspan_5ftag',['open_span_tag',['../cairo_8c.html#a867093342214820735c9ba2639a61163',1,'cairo.c']]],
  ['opendir',['opendir',['../dirent__msvc_8h.html#a56af8d3cfb4a2b2f44e20b276db71f2a',1,'dirent_msvc.h']]],
  ['openlib',['openlib',['../classplplot_1_1core_1_1PLStream.html#ab60146b9e58139fa4042edc86d25b5c0',1,'plplot::core::PLStream']]],
  ['openlink',['Openlink',['../plframe_8c.html#aeebefaec04e51ed012f1a228da6fcad0',1,'Openlink(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#a5d5a15109cfd92b30de260d8859c4659',1,'Openlink(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#a7005483db95c285a3bde1d0f83afca38',1,'Openlink(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#a3b7649b3ec8d467411ab7b7594d82523',1,'Openlink(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
  ['openmap',['OpenMap',['../plmap_8c.html#a1694d58152725317820897aeeef9f18b',1,'plmap.c']]],
  ['operator_20octave_5fvalue',['operator octave_value',['../structoctave__value__ref.html#ab201e4e88c3cdab9759a151e8ab0bf55',1,'octave_value_ref']]],
  ['operator_28_29',['operator()',['../classRand.html#af26fbf390a6ee90604189e59ec910757',1,'Rand::operator()()'],['../classContourable__Data.html#a9b3d26312fbe5f9052f150f10f4e0041',1,'Contourable_Data::operator()()'],['../classCoord__2d.html#ac7363a2e45f0a6ab1f82371fb3beb9d9',1,'Coord_2d::operator()()']]],
  ['operator_2a',['operator*',['../structoctave__value__ref.html#aab197384a2c36352f58c2749fd253c13',1,'octave_value_ref']]],
  ['operator_3d',['operator=',['../classPLNamedMutexLocker.html#ae51462bb922767382a097b88b399ea7a',1,'PLNamedMutexLocker::operator=()'],['../classplstream.html#a2dbfc7548479908d27dab94893aacae1',1,'plstream::operator=()'],['../classoctave__swig__type.html#ab6d91d397ec8158313e7fcca46343a95',1,'octave_swig_type::operator=()']]],
  ['opt',['opt',['../structplplot_1_1__N1.html#a6e723e62d028e42dde3579bd656022dc',1,'plplot::_N1::opt()'],['../structPLOptionTable.html#afd263cc07afcbd7d4837db386f64210a',1,'PLOptionTable::opt()'],['../structDrvOpt.html#a06c031223562962740c6aaebc10d89d6',1,'DrvOpt::opt()']]],
  ['opt_5fa',['opt_a',['../plargs_8c.html#a22b9e603df78ad9759048b0b5aa97b97',1,'opt_a(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a031c7b3bf488e965d3f02edee2e6d4d0',1,'opt_a(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fauto_5fpath',['opt_auto_path',['../plargs_8c.html#a433d97e5b433721cc4f750dcce602723',1,'opt_auto_path(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a6d9a246989841e6394804a3b5b0085fd',1,'opt_auto_path(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fbg',['opt_bg',['../plargs_8c.html#aea3d7fbcbd122cd689a9ee129db5285a',1,'opt_bg(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a3801db071a1f029778ba3acfd1d171b0',1,'opt_bg(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fbufmax',['opt_bufmax',['../plargs_8c.html#a5c0c2b0d3908a9a773afbcacdf5f02d2',1,'opt_bufmax(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a6e931463f4554c701ea1dfde5ef83b81',1,'opt_bufmax(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fcmap0',['opt_cmap0',['../plargs_8c.html#a73d71aa3dda72e024760c58c80866192',1,'opt_cmap0(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a7093b94c507be936dbe1fe443c4f775f',1,'opt_cmap0(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fcmap1',['opt_cmap1',['../plargs_8c.html#a329e90f332db409bd2cc112701492ed2',1,'opt_cmap1(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a48d16285e595fe717cc744621dce4c07',1,'opt_cmap1(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fdb',['opt_db',['../plargs_8c.html#a60b4c1e15df0e594d885f0d688734ea9',1,'opt_db(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#ae36ded1c0479e21ca4b9e3140838bad4',1,'opt_db(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fdebug',['opt_debug',['../plargs_8c.html#a5d840a43d2647b3906d3f6d6cd06795b',1,'opt_debug(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#aea2c4067f497162df2ded4038b2463fa',1,'opt_debug(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fdev',['opt_dev',['../plargs_8c.html#a5c2cd98bf5e69d2ae34d6a7f96fe780f',1,'opt_dev(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a90da905d1de96a446f12a95c95be795c',1,'opt_dev(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fdev_5fcompression',['opt_dev_compression',['../plargs_8c.html#a467eea7dfebb391d25f7d04875010e1e',1,'opt_dev_compression(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a5668b2f91e4ac3afafdc31aee3046d58',1,'opt_dev_compression(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fdpi',['opt_dpi',['../plargs_8c.html#ad59c29a9f3ce0a3fd369841224660f81',1,'opt_dpi(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#aede890282a04cb6611c7bdd5e866d386',1,'opt_dpi(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fdrvopt',['opt_drvopt',['../plargs_8c.html#ac69bb65573b70926a22e1e3e91aa667a',1,'opt_drvopt(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a87286c8a8503175b16de80db684c3d29',1,'opt_drvopt(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5feofill',['opt_eofill',['../plargs_8c.html#a43fcb77df0e18802fa97667f5c0353d2',1,'opt_eofill(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a1a49b696e1c67cb86df30f8d1d7e0aba',1,'opt_eofill(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ffam',['opt_fam',['../plargs_8c.html#af73010cb5a6a4de1861dad372f9c638a',1,'opt_fam(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#af35e3282d6d504ba715501717542292d',1,'opt_fam(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ffbeg',['opt_fbeg',['../plargs_8c.html#a346c3c3bad4c5720fe183ad3c0f7ba8f',1,'opt_fbeg(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#af20c352521f16f7a96d191506c14081d',1,'opt_fbeg(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ffflen',['opt_fflen',['../plargs_8c.html#a2ef82a482c5929ad0f2b7278b7efb69c',1,'opt_fflen(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a1c77c3252e1bf33ab6d026e6f584f8e2',1,'opt_fflen(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ffinc',['opt_finc',['../plargs_8c.html#af012c1aa10aa5b866726f9a914c6b907',1,'opt_finc(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a82ba88ca8174d9766e0cd670eafa5fca',1,'opt_finc(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ffreeaspect',['opt_freeaspect',['../plargs_8c.html#a3af679c429389b13f8837efff7b8a040',1,'opt_freeaspect(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#af7fccb00761dcb99cd9a765517886099',1,'opt_freeaspect(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ffsiz',['opt_fsiz',['../plargs_8c.html#a742b819c524a230e8d85c85c4323a8fb',1,'opt_fsiz(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#ac745e4714af04fbc18b87722a9ea63da',1,'opt_fsiz(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fgeo',['opt_geo',['../plargs_8c.html#a4bb5a9879e585721ffbc17390d63c60d',1,'opt_geo(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a3b3f63714d9215a5f4adf921cf4a4b57',1,'opt_geo(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fh',['opt_h',['../plargs_8c.html#a056c111e7d5ad816e6fa1ccafce74fd1',1,'opt_h(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#ac1c268dd62e1acc95f92441e634f9c86',1,'opt_h(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fhack',['opt_hack',['../plargs_8c.html#a7ca82d657bb43eb71e475957873514b5',1,'opt_hack(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a468b705b4c4a59c7e21fe3251607caeb',1,'opt_hack(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fjx',['opt_jx',['../plargs_8c.html#a2763cff54b7237ea5a439fa5f04c77bc',1,'opt_jx(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a77e085196181f7abac378e9feefce1ac',1,'opt_jx(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fjy',['opt_jy',['../plargs_8c.html#a4876a664990d0d54e7cc5d566fb7de2e',1,'opt_jy(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a1af2968fc47ea2cbbd3221c43bbd00b5',1,'opt_jy(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5flocale',['opt_locale',['../plargs_8c.html#a7d8a254eab4dc3049103dd6542590b1f',1,'opt_locale(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a77c4a1eb559afa8db5d54ad2eff43fc7',1,'opt_locale(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fmar',['opt_mar',['../plargs_8c.html#ada02ad1a23de63a8f29be293c7f81916',1,'opt_mar(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a6c3dd40f998e3542bb07aaa1101445b2',1,'opt_mar(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fmfi',['opt_mfi',['../plargs_8c.html#a0691712e0b1f0e6bce154e73384870b8',1,'opt_mfi(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#aac929d3bf383d5ed8684770d833da22e',1,'opt_mfi(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fmfo',['opt_mfo',['../plargs_8c.html#ac7a8dc3bdb60db4292bafe73e79257a3',1,'opt_mfo(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#aa4b29828c54f889d442ad57608d25680',1,'opt_mfo(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fncol0',['opt_ncol0',['../plargs_8c.html#ab448ff3aa598dadd225c9138cb870ec4',1,'opt_ncol0(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a83d65ee7aa9945a738d50ddda2a5fe20',1,'opt_ncol0(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fncol1',['opt_ncol1',['../plargs_8c.html#a471313fd89e67969eb0c637a2c8c416b',1,'opt_ncol1(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a7073df66d085f663f7138106acf939e9',1,'opt_ncol1(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fnopixmap',['opt_nopixmap',['../plargs_8c.html#afe5f63dfc95f2ac3f0cb43d218dbba2b',1,'opt_nopixmap(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#ade3fdc68c8d6d754a29a552dcad80b86',1,'opt_nopixmap(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fnp',['opt_np',['../plargs_8c.html#a3ab4abbf0e5808ee807e58e843542ad5',1,'opt_np(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a73d3604cb18348c751969639d54ca851',1,'opt_np(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fo',['opt_o',['../plargs_8c.html#af3939a237c84e94053bb947b6c83db8f',1,'opt_o(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#afeb605ff7e970d4c152c14a18fbb3366',1,'opt_o(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fori',['opt_ori',['../plargs_8c.html#ac060ad205cd1ca195eef5e8e00622996',1,'opt_ori(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a7b352b1d7b4071f790fd98b36a451de2',1,'opt_ori(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fplserver',['opt_plserver',['../plargs_8c.html#a882eadf9921e3aae3698475546d27eba',1,'opt_plserver(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a59d97bbe9b4627230590a2c1c89cad49',1,'opt_plserver(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fplwindow',['opt_plwindow',['../plargs_8c.html#ad05a22bbd6ed30eee5c2a5ba06ecfafa',1,'opt_plwindow(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#ab7782c320d943e9f1c52b12e1a7c9d68',1,'opt_plwindow(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fportrait',['opt_portrait',['../plargs_8c.html#a2b0dc8dcf79017e752de813ccc4bbe7f',1,'opt_portrait(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a36519f159de0f59425da35c2ee3abd46',1,'opt_portrait(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fpx',['opt_px',['../plargs_8c.html#a216219cfbabd3488ad68932374d0add0',1,'opt_px(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a8050d25e5544c123a6190a113fa42054',1,'opt_px(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fpy',['opt_py',['../plargs_8c.html#ae0b1fef05d6e48ad3ab9a6570d5fc0b4',1,'opt_py(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a2f5cc5922bc2eb5f7de7b3f39357a88d',1,'opt_py(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fserver_5fname',['opt_server_name',['../plargs_8c.html#a079802ce2301f7daf04f495adaffdaf2',1,'opt_server_name(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#aba6c88698b2ea40fc4cebfc6d2092c8c',1,'opt_server_name(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5ftk_5ffile',['opt_tk_file',['../plargs_8c.html#ac2cc49e987db83a8ebf3634f85a22fc5',1,'opt_tk_file(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a2ddec252f09ecdd79c5b52399c0747b6',1,'opt_tk_file(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fv',['opt_v',['../plargs_8c.html#ae43a572ce862652bdddaf4db9db3a932',1,'opt_v(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a6dd108524a4ce6158d32a9c032586c70',1,'opt_v(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fverbose',['opt_verbose',['../plargs_8c.html#a8c582de79220166fe9e929ac720576a2',1,'opt_verbose(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a2937bf7b95cf26a0887c85c58600205d',1,'opt_verbose(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fwidth',['opt_width',['../plargs_8c.html#a61236c7e1a1f8b03fdb8dfbf60e412a0',1,'opt_width(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a65cf6211752a80054157629f5abf25b8',1,'opt_width(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['opt_5fwplt',['opt_wplt',['../plargs_8c.html#a799666480897f06b9362fec1c6e6bc3b',1,'opt_wplt(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a4051f4ef06cfab9d71881a9a89977e9f',1,'opt_wplt(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
  ['option',['option',['../structDrvOptCmd.html#a917cd988483f737f6a44e769c31a9432',1,'DrvOptCmd']]],
  ['options',['options',['../structPLOptionInfo.html#a2c426d695c239e1377d59ea04301fe80',1,'PLOptionInfo::options()'],['../tclMain_8c.html#a9c426a6e467ca57cd72f5637f5928d6e',1,'options():&#160;tclMain.c']]],
  ['optmax',['OPTMAX',['../plargs_8c.html#ab15b74b20e79bea4b60b1b6bba1216e3',1,'plargs.c']]],
  ['opttmp',['opttmp',['../plargs_8c.html#a139fcf820c58a2331e102cd367a8f158',1,'plargs.c']]],
  ['optusage',['OptUsage',['../classplstream.html#af54356617be65cdf161918e3430321df',1,'plstream::OptUsage()'],['../classplplot_1_1core_1_1PLStream.html#af6dd6dd9be106f386255eafc03d5c5fa',1,'plplot.core.PLStream.OptUsage()']]],
  ['orchid',['Orchid',['../plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba2a4b392d52ff5f8074a7ddded3984e75',1,'plstream.h']]],
  ['order',['order',['../structtriangle.html#a8b3d3cd3631f47f800a289afd43a9ccb',1,'triangle']]],
  ['orient',['orient',['../namespacePlframe.html#a82eaf9961ca3b88bf86e7c98651cdfaa',1,'Plframe.orient()'],['../plframe_8c.html#a2c41613105823b4f75157ad917403a10',1,'Orient(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#abfec6bcd9be71987ed497b7539fda236',1,'Orient(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#a6e0a64c115acc82e8c89c2b776f1c407',1,'Orient(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#af8841f8e4aaafd7f8f958211c7cb5788',1,'Orient(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
  ['orientation',['ORIENTATION',['../plplotP_8h.html#ac815b03ec48abf99301f44140ff0b0a9',1,'plplotP.h']]],
  ['original_5fchrdef',['original_chrdef',['../structPLStream.html#a1c96071977b830441e8dc0b6d1ea0323',1,'PLStream']]],
  ['original_5fchrht',['original_chrht',['../structPLStream.html#ab8a4ab4b5ce5ed5892455da26b638af3',1,'PLStream']]],
  ['originchanger',['OriginChanger',['../classOriginChanger.html',1,'OriginChanger'],['../classOriginChanger.html#aa86ed32c05b1252ec0829eaf59fa77cf',1,'OriginChanger::OriginChanger()']]],
  ['outfile',['outfile',['../structcdImageStruct.html#a50e8cb41a845ade846fb57652c4e7c83',1,'cdImageStruct::outfile()'],['../structPLStream.html#a60e06589a87b44963d348f430d7a6b24',1,'PLStream::OutFile()']]],
  ['output_5ftype',['output_type',['../structPLStream.html#ab6a87dc559f780569957bdd96f586e2e',1,'PLStream']]],
  ['overlined',['overlined',['../classQtPLDriver.html#ad5312b0059aeaa32a1742e6e9e4d418d',1,'QtPLDriver']]],
  ['ovl',['ovl',['../structoctave__value__ref.html#aa0e2752ab23498ca52528a35fa108d27',1,'octave_value_ref']]],
  ['own',['own',['../structswig__lua__userdata.html#a12970d19b437f84b1e7fba18ede882cb',1,'swig_lua_userdata::own()'],['../structswig__lua__rawdata.html#ac52566bcb4a7b4d8421c17d182048924',1,'swig_lua_rawdata::own()'],['../classoctave__swig__type.html#ab9e07dcba7290f802cbc551323f555eb',1,'octave_swig_type::own()'],['../structSwigPyObject.html#a83cb6489fb1b171467f06c091ae6f283',1,'SwigPyObject::own()']]],
  ['owndata',['owndata',['../structswig__type__info.html#a93c25d5903cbfcb82208eea7227c32bd',1,'swig_type_info']]]
];
